package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````,)P$"#0```#XNP```````#0`(``'
M`"@`&P`:``8````T````-(`$"#2`!`C@````X`````4````$`````P```!0!
M```4@00(%($$"!,````3````!`````$````!``````````"`!`@`@`0(/+8`
M`#RV```%`````!````$````\M@``/$8%"#Q&!0AP`@``U!(```8`````$```
M`@```%"V``!01@4(4$8%"/@```#X````!@````0````$````*`$``"B!!`@H
M@00((````"`````$````!````%'E=&0```````````````````````````8`
M```$````+VQI8B]L9"UL:6YU>"YS;RXR```$````$`````$```!'3E4`````
M``(````&````"````&$```!S````"@``````````````0@````````!'````
M1@``````````````60```#T````X````2@````,```!7`````````#````!>
M````5````&D```!K````9@````0````K```````````````I````8@```$4`
M````````;P```&,```!(````9`````@`````````40```'(````!````3```
M```````>`````````'``````````4````&T``````````````&4````G````
M3@```#D``````````````&X````T````/P```$0``````````````!(`````
M````/@``````````````(@`````````;````+P````L````Q````*````%,`
M`````````````%H```!/````.P```%T```!+````.@```#,`````````#```
M`````````````````%4```!L`````````$,```!<````00```#P````F````
M````````````````````````````````````````````````````````````
M`````````$T```````````````````````````````X`````````#P```!0`
M``!?````````````````````$P``````````````$0`````````8````````
M`````````````````%@`````````5@````````!G```````````````0````
M````````````````&@`````````E````:````",````'`````````"X````D
M````#0```!P`````````8````"``````````&0````D``````````````$``
M````````,@```!T````M`````````'$```!;`````````$D````&````````
M``````!J````````````````````````````````````(0``````````````
M%P`````````U`````````"H`````````````````````````%@`````````5
M`````````%(`````````!0```````````````````&$````V`````@``````
M```?````+````#<````E````30````@````(`````!`0!"5`!("H$0`!HH9!
MJ$````)+*$0I.*(R1XH$#(A-````3P```````````````````%(```!4````
M50````````!6````5P````````!8````60```%H`````````6P``````````
M`````````%P```!?``````````````!@````8@```&,```!E`````````&<`
M``!J`````````&P```!M````;@```'``````````R-6R<5GH[>SF_S"BSMY'
M+:/@^TGJT^\.I]VC:R_%F[;;S>.>A_F<@6L)0]8-.I<+Q8D%D`T4XIXA_^0.
ML@&+;\2YG$!K?YI\?ZF<FV[%WQ_9<5@<N^.2?-1DU'RM2^/`,F+;[>&G`@IF
MK\QF8!;)67OP2FOB1\8!0T75[$?L,SI]08[%PN4_++>`A63RV],=^J%L8+F-
M\0X`````````````````````-0,````````F````$@```+$`````````#0``
M`!(```"#`P```````#4````2````;@,```````!#````$@```*$!````````
M,P```!(```!Z`@```````"$%```2````$0``````````````(````"``````
M`````````"````!T`P```````-0"```2````C0$````````-````$@```",$
M````````20```!(```!N`0````````T````2````@`$````````+````$@``
M`$X#````````.0$``!(````>`P```````"@!```2````^`(```````"G````
M$@```"P"````````$`0``!(```#]`````````!L#```2````'`(````````X
M````$@```)\#````````0P```!(```#*`0```````#0!```2````!P0`````
M``"]`0``$@```-<"````````<P```!(``````P```````(`````2````F`(`
M``````!\`0``$@```.H!````````%P```!(```"F`0```````"\!```2````
M-0(```````!5`P``$@```"T$````````20```!(```#Y`P```````$,````2
M````+P$````````-````$@```+H#````````B````!(````T`````````(X`
M```2````P@,```````!#````$@```%T!````````,P$``!(```#(````````
M`)P&```2````YP,```````#=````$@```+,#````````90```!(```#@`P``
M`````/,#```2````F`,```````"O````$@```&<#````````/P```!(```#K
M!````````!P!```2````00$````````_`0``$@```-`#````````$0```!(`
M``!<`@```````-T"```2````10,```````!-````$@```.L"````````=0``
M`!(```!.`@```````$T3```2````I@,```````"H`0``$@```)$"````````
MA`$``!(```"K`0```````,D````2````5@,````````<````$@```*T#````
M````/P```!(```"1`P```````.D````2````[``````````-````$@```$(`
M````````"P```!(```#7`P```````$4````2````\0,```````!8````$@``
M`-<`````````.````!(```#^`0````````T````2````A0(```````!9````
M$@```%`!````````E````!(```!\`P```````)L!```2````/0,```````#W
M````$@```/$"````````X````!(````=`0````````T````2````0P(`````
M```(`P``$@```%0`````````6P```!(```"*`P```````$(````2````V`$`
M```````7````$@```&,`````````#0```!(`````!````````"4````2````
MCP`````````-````$@```#`#````````^P```!(```!X`````````&`````2
M````"P$```````#$"```$@```+<!``"DEP0(1@```!(```",!```@-@$"`0`
M```1``\`8@4``(#;!`BX6@``$0`/`&P%``!DP00(10@``!(`#0"8!0``[:8$
M"/4!```2``T`A@0``%C8!`@`````$@`.`!L$``#`2`4(!````"$`&`!>!```
MGZ($"`T````2``T`)`4``'#7!`A<````$@`-`*````!TF00(1@```!(````/
M!0``D$@%"``````0`!<`$04``)!(!0@`````(``7`!H$``#`2`4(!````"$`
M&`!\!```8-<$"`4````2``T`BP4``*RB!`C9`@``$@`-`*D$``#BJ`0(6@``
M`!(`#0`9!```P$@%"`0````1`!@`%`0``"O4!`@!`P``$@`-`-D$``#XOP0(
M0````!(`#0#T!```#\L$"'<````2``T`300``*Q(!0@`````$`#Q_UD$```0
M604(`````!``\?^3!```NLX$"`4%```2``T`#P,``(38!`@$````$0`/`!4%
M```PG`0(`````!(`#0"W!```BJ$$"!4!```2``T`S00``,&E!`@L`0``$@`-
M```%``"H2`4(!````!$`%P!J`@``9)D$"*(&```2````;P0``(6E!`@\````
M$@`-`$8$``"L2`4(`````!``\?]=!0``I$@%"`0````1`!<`-`4``%O.!`A?
M````$@`-`!P%``#HG`0(0````!(`#0!0!0``J<D$"&8!```2``T`HP(``,1(
M!0@3````$0`8`'D%```XP`0(+`$``!(`#0`>!0``!)<$"``````2``L``&QI
M8G!E<FPN<V\N-2XQ,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S
M<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?
M:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T
M;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])
M8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P
M='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA
M9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?
M<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O
M7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS
M;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`&QS965K-C0`
M<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S<')I;G1F`'-T<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`7V9P7VAW`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?7V1A=&%?<W1A<G0`
M>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!
M4E-404-+`'!A<E]R;71M<&1I<@!N86UE7VQO861?;65?,@!P87)?;6MT;7!D
M:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N
M=@!'3$E"0U\R+C``1TQ)0D-?,BXR`$=,24)#7S(N-`!'3$E"0U\R+C,`1TQ)
M0D-?,BXS+C(``````@````(``@````````````(````#```````"``0`!0``
M```````"`````@`&``8```````(````#``(````"````!P```````P`"``(`
M`@`"``(````"`````@`&`````@`"````"``"``(```````(``@``````````
M``(``@`%``````````(```````(````"``````````$``0`!``$``0`"``$`
M`0````$``0`"``$``0`!``(``0`!``$``0`!``$``0`!``$``0`!`````0`!
M``$``0`!``$````!``$``0`"`,<"```0````,````!!I:0T```8`I04``!``
M```2:6D-```%`*\%`````````0`%``4#```0`````````!1I:0T```@`N04`
M`!`````3:6D-```'`,,%```0````<AEI"0``!`#-!0``$````!)I:0T```,`
MKP4``!`````0:6D-```"`*4%````````2$<%"`8'``#`2`4(!5T``,1(!0@%
M<```6$<%"`<!``!<1P4(!P(``&!'!0@'`P``9$<%"`<$``!H1P4(!P4``&Q'
M!0@'!@``<$<%"`=-``!T1P4(!P<``'A'!0@'"0``?$<%"`<*``"`1P4(!PL`
M`(1'!0@'#```B$<%"`<-``",1P4(!PX``)!'!0@'#P``E$<%"`<0``"81P4(
M!Q$``)Q'!0@'$@``H$<%"`<3``"D1P4(!Q0``*A'!0@'%0``K$<%"`<6``"P
M1P4(!Q<``+1'!0@'&```N$<%"`<9``"\1P4(!QH``,!'!0@'&P``Q$<%"`<<
M``#(1P4(!QT``,Q'!0@''@``T$<%"`<?``#41P4(!R```-A'!0@'(0``W$<%
M"`<B``#@1P4(!VD``.1'!0@'5@``Z$<%"`<C``#L1P4(!R0``/!'!0@')0``
M]$<%"`<F``#X1P4(!R<``/Q'!0@'*````$@%"`<I```$2`4(!RH```A(!0@'
M*P``#$@%"`<L```02`4(!RT``!1(!0@'+@``&$@%"`<O```<2`4(!S```"!(
M!0@',0``)$@%"`<R```H2`4(!S,``"Q(!0@'-```,$@%"`<U```T2`4(!S8`
M`#A(!0@'-P``/$@%"`<X``!`2`4(!SD``$1(!0@'.@``2$@%"`<[``!,2`4(
M!SP``%!(!0@'/0``5$@%"`<^``!82`4(!S\``%Q(!0@'0```8$@%"`=!``!D
M2`4(!T(``&A(!0@'0P``;$@%"`=$``!P2`4(!T4``'1(!0@'1@``>$@%"`='
M``!\2`4(!T@``(!(!0@'20``A$@%"`=*``"(2`4(!TL``(Q(!0@'3```58GE
M4X/L!.@`````6X'#/+```(N3_/___X72=`7HC@```.B5!0``Z`!!``!86\G#
M_S501P4(_R541P4(`````/\E6$<%"&@`````Z>#_____)5Q'!0AH"````.G0
M_____R5@1P4(:!````#IP/____\E9$<%"&@8````Z;#_____)6A'!0AH(```
M`.F@_____R5L1P4(:"@```#ID/____\E<$<%"&@P````Z8#_____)71'!0AH
M.````.EP_____R5X1P4(:$````#I8/____\E?$<%"&A(````Z5#_____)8!'
M!0AH4````.E`_____R6$1P4(:%@```#I,/____\EB$<%"&A@````Z2#_____
M)8Q'!0AH:````.D0_____R601P4(:'````#I`/____\EE$<%"&AX````Z?#^
M____)9A'!0AH@````.G@_O___R6<1P4(:(@```#IT/[___\EH$<%"&B0````
MZ<#^____):1'!0AHF````.FP_O___R6H1P4(:*````#IH/[___\EK$<%"&BH
M````Z9#^____);!'!0AHL````.F`_O___R6T1P4(:+@```#I</[___\EN$<%
M"&C`````Z6#^____);Q'!0AHR````.E0_O___R7`1P4(:-````#I0/[___\E
MQ$<%"&C8````Z3#^____)<A'!0AHX````.D@_O___R7,1P4(:.@```#I$/[_
M__\ET$<%"&CP````Z0#^____)=1'!0AH^````.GP_?___R781P4(:``!``#I
MX/W___\EW$<%"&@(`0``Z=#]____)>!'!0AH$`$``.G`_?___R7D1P4(:!@!
M``#IL/W___\EZ$<%"&@@`0``Z:#]____)>Q'!0AH*`$``.F0_?___R7P1P4(
M:#`!``#I@/W___\E]$<%"&@X`0``Z7#]____)?A'!0AH0`$``.E@_?___R7\
M1P4(:$@!``#I4/W___\E`$@%"&A0`0``Z4#]____)01(!0AH6`$``.DP_?__
M_R4(2`4(:&`!``#I(/W___\E#$@%"&AH`0``Z1#]____)1!(!0AH<`$``.D`
M_?___R442`4(:'@!``#I\/S___\E&$@%"&B``0``Z>#\____)1Q(!0AHB`$`
M`.G0_/___R4@2`4(:)`!``#IP/S___\E)$@%"&B8`0``Z;#\____)2A(!0AH
MH`$``.F@_/___R4L2`4(:*@!``#ID/S___\E,$@%"&BP`0``Z8#\____)31(
M!0AHN`$``.EP_/___R4X2`4(:,`!``#I8/S___\E/$@%"&C(`0``Z5#\____
M)4!(!0AHT`$``.E`_/___R5$2`4(:-@!``#I,/S___\E2$@%"&C@`0``Z2#\
M____)4Q(!0AHZ`$``.D0_/___R502`4(:/`!``#I`/S___\E5$@%"&CX`0``
MZ?#[____)5A(!0AH``(``.G@^____R5<2`4(:`@"``#IT/O___\E8$@%"&@0
M`@``Z<#[____)61(!0AH&`(``.FP^____R5H2`4(:"`"``#IH/O___\E;$@%
M"&@H`@``Z9#[____)7!(!0AH,`(``.F`^____R5T2`4(:#@"``#I</O___\E
M>$@%"&A``@``Z6#[____)7Q(!0AH2`(``.E0^____R6`2`4(:%`"``#I0/O_
M__\EA$@%"&A8`@``Z3#[____)8A(!0AH8`(``.D@^____R6,2`4(:&@"``#I
M$/O__P```````````````#'M7HGA@^3P4%12:&#7!`AH<-<$"%%6:"O4!`CH
M0_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/=A(!0@`=4"X2$8%"(L5W$@%
M""U$1@4(P?@"C5C_.=IS'XVV`````(U"`:/<2`4(_Q2%1$8%"(L5W$@%"#G:
M<N?&!=A(!0@!6%M=PXVV`````(V_`````%6)Y8/L"(L53$8%"(72=!:X````
M`(7`=`V#[`QH3$8%"/_0@\00R<-5B>6#[!C'1?R(V`0(@^P,:@#HM?[__X/$
M$(L`@^P,4.B7^___@\00_W7\:&29!`AHDM@$"%#H8?[__X/$$,G#58GE4X'L
M)!```(M%#(F%Z.___XM%$(F%Y.___V6A%````(E%^#'`@^P$:/\/``"-A?CO
M__]0:*[8!`CH?/W__X/$$(F%].___X.]].___P!^&(N%].___TB*A`7X[___
MA,!U!O^-].___X.]].___P!^6XN%].___X/L!%!J+XV%^.___U#HD?W__X/$
M$(7`=#R+G?3O__^#[`QJ`.CJ_?__@\00BP"#[`Q0Z,SZ__^#Q!")PE.-A?CO
M__]0_[7H[___4N@3_/__@\00ZS.#[`QJ`.BT_?__@\00BP"#[`Q0Z);Z__^#
MQ!"#[`3_M>3O____M>CO__]0Z%[Z__^#Q!"+1?AE,P44````=`7H6OS__XM=
M_,G#58GE@^P8@WT(`'0)H<!(!0B%P'4,QT7L`````.F8````BT4(B47TZP/_
M1?2+5?2*`H3`=`F+3?2*`3P]=>N+5?2+10B)T2G!B4WPH<!(!0B)1?CK3XM%
M\(/L!%#_=0C_=?SHKOS__X/$$(7`=3*+1?`#1?R*`#P]=2:+5?BAP$@%"(G1
M*<&)R,'X`HG"BT4,B1"+1?!`BU7\`<*)5>SK&8-%^`2+3?B+"8E-_(-]_`!U
MH\=%[`````"+1>S)PU6)Y8/L&(/L"(U%_%#_=0CH+?___X/$$,G#58GE4X/L
M)(M5#(H"/#UU`_]%#(/L#/]U#.B?^O__@\00B47X@^P(C47T4/]U".CU_O__
M@\00B47@@WW@`'1!@^P,_W7@Z'/Z__^#Q!`[1?@/@O\```"+30R*`8M5X(@"
MBTW@B@&$P`^5P/]%X/]%#(3`=>+'1=P`````Z9X!``"AP$@%"(E%Z,=%Y```
M``#K!X-%Z`3_1>2+5>B+`H7`=?"AX$@%"(7`=#:+1>2#P`+!X`*+%<!(!0B#
M[`A04NCJ]___@\00H\!(!0BAP$@%"(7`=67'1=S_____Z3X!``#'!>!(!0@!
M````BT7D@\`"P>`"@^P,4.AA^O__@\00B47H@WWH`'4,QT7<_____^D*`0``
MBT7DP>`"BQ7`2`4(@^P$4%+_=>CHL/K__X/$$(M-Z(D-P$@%"(L5P$@%"(M%
MY$#!X`*-!`+'``````"+1>2)1?2+10B)1>#K`_]%X(M5X(H"A,!T"8M-X(H!
M/#UUZXL5P$@%"(M%],'@`HT<`HM5X(M%"(G1*<&)R`-%^(/``H/L#%#HP?G_
M_X/$$(D#BP.%P'4)QT7<_____^MNBQ7`2`4(BT7TP>`"C00"BP")1>#K`_]%
MX(M%"(H`BU7@B`*+3>"*`83`#Y7`_T4(@_`!A,!U"8M5X(H"/#UUUHM-X,8!
M/?]%X(M5#(H"BTW@B`&+5>"*`H3`#Y7`_T7@_T4,A,!UXL=%W`````"+1=R+
M7?S)PU6)Y8/L&.LMBQ7`2`4(BT7\P>`"`<*)5>R+1>R#P`2+`(M5[(D"BU7L
MBP*%P'0&@T7L!.OD@^P(C47\4/]U".B^_/__@\00A<!UO<G#58GE@>P8(```
M9:$4````B47\,<#'A?3?__\`````Z+?U__]HP=@$"%!HQ=@$"(V%^^___U#H
M@/7__X/$$(F%\-___X.]\-___P!Y#\>%[-___P````#IH0```(/L!&@`$```
MC87ZW___4(V%^^___U#HY/C__X/$$(F%\-___X.]\-___P!Y#,>%[-___P``
M``#K:(N%\-___T"#[`Q0Z$;X__^#Q!")A?3?__^#O?3?__\`=0S'A>S?__\`
M````ZSJ+A?#?__^#[`10C87ZW___4/^U]-___^A,]___@\00BX7PW___`X7T
MW___Q@``BY7TW___B97LW___BX7LW___BU7\93,5%````'0%Z/?W___)PU6)
MY8/L".C@_O__R<-5B>6![#@0``"+10B)A=SO__^+10R)A=CO__]EH10```")
M1?PQP(/L#&C1V`0(Z![\__^#Q!")A>SO__^AF$@%"(/L"%#_M=SO___H:/?_
M_X/$$(7`=">#[`C_M=SO__]HVM@$".@!_/__@\00BY7<[___B974[___Z4("
M``"#[`S_M=SO___HG/;__X/$$(F%].___Z&<2`4(@^P(4/^UV.___^A?]___
M@\00B87X[___Z=H!``"+A?CO__^*`(3`=0K'A?CO___GV`0(@[WL[___`'0Y
M@^P(_[7X[____[7L[___Z#[X__^#Q!"%P'4>H9Q(!0B#[`A0:@#H!_?__X/$
M$(F%^.___^F"`0``@^P,_[7X[___Z`OV__^#Q!")A?#O___K%?^-\.___XN%
M\.___P.%^.___\8``(N%\.___T@#A?CO__^*$*&82`4(B@`XPG31BX7P[___
M0`.%].___SW_#P``?B>#[`C_M=SO__]HVM@$".CM^O__@\00BX7<[___B874
M[___Z2X!``"AF$@%"(/L#/^UW.___U#_M?CO__]HZ=@$"(V%_.___U#HX/+_
M_X/$((/L#&H`Z$/W__^#Q!"+`(/L#%#H)?3__X/$$(/L#%#H2?;__X/$$(/L
M"%"-A?SO__]0Z#(S``"#Q!"%P'5_@^P,:@#H!??__X/$$(L`@^P,4.CG\___
M@\00@^P,4.@+]O__@\00BT`0)0#P```]`(```'5)@^P(:@&-A?SO__]0Z"CT
M__^#Q!"%P'4Q@^P(C87\[___4&C:V`0(Z!#Z__^#Q!"#[`R-A?SO__]0Z(OV
M__^#Q!")A=3O___K2*&<2`4(@^P(4&H`Z(#U__^#Q!")A?CO__^#O?CO__\`
M#X49_O__@^P(_[7<[___:-K8!`CHNOG__X/$$(N5W.___XF5U.___XN%U.__
M_XM5_&4S%10```!T!>@1]?__R<-5B>6#[!"+10B)1?R+10B)1?CK&HM%^(H0
MH9A(!0B*`#C"=0>+1?A`B47\_T7XBT7XB@"$P'7=BT7\R<-5B>6#[`B#?0@`
M=`F+10B*`(3`=1B#[`QHY]@$".C!]?__@\00B47XZ?H```"#[`S_=0CHV_/_
M_X/$$$B+50@!PHE5_.L#_TW\BTW\.TT(=A:+5?R*`HL5F$@%"(H2.-!TY.L#
M_TW\BTW\.TT(=A&+5?R*`HL5F$@%"(H2.-!UY(M-_#M-"'4\BU7\B@*+%9A(
M!0B*$CC0=16#[`QHY]@$".@]]?__@\00B47XZWFAF$@%"(/L#%#H)_7__X/$
M$(E%^.MC_TW\BTW\.TT(=A&+5?R*`HL5F$@%"(H2.-!TY(M5_(M%"(G1*<&)
MR(/``CT`$```=@G'1?@`````ZRB+5?R+10B)T2G!B<A`@^P$4/]U"&@`204(
MZ#;Q__^#Q!#'1?@`204(BT7XR<-5B>575H/L0&6A%````(E%]#'`C572B57$
MQT7`G-D$",=%O`@```"+?<2+=<"+3;SSI8EUP(E]Q(M5P(L"BTW$9HD!@T7$
M`H-%P`*#[`QH\-@$".CX^?__@\00@^P,:`#9!`CHZ/G__X/$$(/L#&C1V`0(
MZ-CY__^#Q!"#[`QH#-D$".C(^?__@\00@^P,:!;9!`CHN/G__X/$$(/L#&@@
MV00(Z*CY__^#Q!"#[`QHVM@$".B8^?__@\00@^P,:"K9!`CHB/G__X/$$(/L
M#&@SV00(Z'CY__^#Q!"#[`QH/MD$".@H]___@\00B47,@WW,`'03@^P(_W7,
M:!;9!`CH)O?__X/$$(/L#&A/V00(Z/SV__^#Q!")1<R#?<P`=!.#[`C_=<QH
M8=D$".CZ]O__@\00@^P,:&S9!`CHT/;__X/$$(E%S(-]S`!T%8/L"/]US&C1
MV`0(Z,[V__^#Q!#K9X/L#&A\V00(Z*+V__^#Q!")1<R#?<P`=!6#[`C_=<QH
M#-D$".B@]O__@\00ZSF-1=*#P!&)1<R#[`1J"FB-V00(_W7,Z+WR__^#Q!"%
MP'47BT7,@\`*@^P(4&@,V00(Z&7V__^#Q!"#[`AHF-D$"&CPV`0(Z%#V__^#
MQ!"+=?1E,S44````=`7HN?'__XUE^%Y?7<-5B>6#[!BAH$@%"(/X_W5#@^P,
M:`S9!`CH_O7__X/$$(E%_(-]_`!T&XM%_(H`A,!T$HM%_(H`/#!T"<=%[`$`
M``#K!\=%[`````"+1>RCH$@%"*&@2`4(R<-5B>53@>QP`0``BT4(@\`<B47T
MQT7X`````.M#BT7TBP")1?"#1?0$BTWXBT7PB<+!XAB+1?#!X`@E``#_``G"
MBT7PP>@()0#_```)PHM%\,'H&`G0B82-F/[___]%^(-]^`]^M\=%^!````#K
M7HM-^(M%^(/H`XN4A9C^__^+1?B#Z`B+A(68_O__,<*+1?B#Z`Z+A(68_O__
M,<*+1?B#Z!"+A(68_O__,=")A(V8_O__BU7XBT7XBX2%F/[__\'('XF$E9C^
M____1?B#??A/?IR+10B+`(E%[(M%"(M`!(E%Z(M%"(M`"(E%Y(M%"(M`#(E%
MX(M%"(M`$(E%W(V%F/[__XE%V(M%[(G!P<D;BU7DBT7H(<*+1>CWT"-%X`G0
MC00!B<(#5=R+1=B+`(T$`@69>8):B47P@T78!,%-Z`*+1?")P<')&XM5Z(M%
M["'"BT7L]]`C1>0)T(T$`8G"`U7@BT78BP"-!`(%F7F"6HE%W(-%V`3!3>P"
MBT7<B<'!R1N+5>R+1?`APHM%\/?0(T7H"="-!`&)P@-5Y(M%V(L`C00"!9EY
M@EJ)1>"#1=@$P4WP`HM%X(G!P<D;BU7PBT7<(<*+1=SWT"-%[`G0C00!B<(#
M5>B+1=B+`(T$`@69>8):B47D@T78!,%-W`*+1>2)P<')&XM5W(M%X"'"BT7@
M]]`C1?`)T(T$`8G"`U7LBT78BP"-!`(%F7F"6HE%Z(-%V`3!3>`"BT7HB<'!
MR1N+5>"+1>0APHM%Y/?0(T7<"="-!`&)P@-5\(M%V(L`C00"!9EY@EJ)1>R#
M1=@$P4WD`HM%[(G!P<D;BU7DBT7H(<*+1>CWT"-%X`G0C00!B<(#5=R+1=B+
M`(T$`@69>8):B47P@T78!,%-Z`*+1?")P<')&XM5Z(M%["'"BT7L]]`C1>0)
MT(T$`8G"`U7@BT78BP"-!`(%F7F"6HE%W(-%V`3!3>P"BT7<B<'!R1N+5>R+
M1?`APHM%\/?0(T7H"="-!`&)P@-5Y(M%V(L`C00"!9EY@EJ)1>"#1=@$P4WP
M`HM%X(G!P<D;BU7PBT7<(<*+1=SWT"-%[`G0C00!B<(#5>B+1=B+`(T$`@69
M>8):B47D@T78!,%-W`*+1>2)P<')&XM5W(M%X"'"BT7@]]`C1?`)T(T$`8G"
M`U7LBT78BP"-!`(%F7F"6HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0APHM%
MY/?0(T7<"="-!`&)P@-5\(M%V(L`C00"!9EY@EJ)1>R#1=@$P4WD`HM%[(G!
MP<D;BU7DBT7H(<*+1>CWT"-%X`G0C00!B<(#5=R+1=B+`(T$`@69>8):B47P
M@T78!,%-Z`*+1?")P<')&XM5Z(M%["'"BT7L]]`C1>0)T(T$`8G"`U7@BT78
MBP"-!`(%F7F"6HE%W(-%V`3!3>P"BT7<B<'!R1N+5>R+1?`APHM%\/?0(T7H
M"="-!`&)P@-5Y(M%V(L`C00"!9EY@EJ)1>"#1=@$P4WP`HM%X(G!P<D;BU7P
MBT7<(<*+1=SWT"-%[`G0C00!B<(#5>B+1=B+`(T$`@69>8):B47D@T78!,%-
MW`*+1>2)P<')&XM5W(M%X"'"BT7@]]`C1?`)T(T$`8G"`U7LBT78BP"-!`(%
MF7F"6HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0APHM%Y/?0(T7<"="-!`&)
MP@-5\(M%V(L`C00"!9EY@EJ)1>R#1=@$P4WD`HM%[(G!P<D;BU7DBT7H(<*+
M1>CWT"-%X`G0C00!B<(#5=R+1=B+`(T$`@69>8):B47P@T78!,%-Z`*+1?")
MP<')&XM5Z(M%["'"BT7L]]`C1>0)T(T$`8G"`U7@BT78BP"-!`(%F7F"6HE%
MW(-%V`3!3>P"BT7<B<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(%
MH>O9;HE%X(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78
MBP"-!`(%H>O9;HE%Y(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"
M`U7LBT78BP"-!`(%H>O9;HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%
MW(T$`8G"`U7PBT78BP"-!`(%H>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+
M1>@QT#-%X(T$`8G"`U7<BT78BP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7PB<'!
MR1N+5>B+1>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!3>P"
MBT7<B<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%X(-%
MV`3!3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%H>O9
M;HE%Y(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78BP"-
M!`(%H>O9;HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"`U7P
MBT78BP"-!`(%H>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%X(T$
M`8G"`U7<BT78BP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7PB<'!R1N+5>B+1>PQ
MT#-%Y(T$`8G"`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!3>P"BT7<B<'!R1N+
M5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%X(-%V`3!3?`"BT7@
MB<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%H>O9;HE%Y(-%V`3!
M3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78BP"-!`(%H>O9;HE%
MZ(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"`U7PBT78BP"-!`(%
MH>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%X(T$`8G"`U7<BT78
MBP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7PB<'!R1N+5>B+1>PQT#-%Y(T$`8G"
M`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!3>P"BT7<B<'!R1N+5>R+1?`QT#-%
MZ(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%X(-%V`3!3?`"BT7@B<'!R1N+5?"+
M1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%H>O9;HE%Y(-%V`3!3=P"BT7DB</!
MRQN+5?"+1=P)T(G!(TW@BU7PBT7<(=`)R(T$`XG"`U7LBT78BP"-!`(M)$/D
M<(E%Z(-%V`3!3>`"BT7HB</!RQN+5=R+1>`)T(G!(TWDBU7<BT7@(=`)R(T$
M`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!3>0"BT7LB</!RQN+5>"+1>0)
MT(G!(TWHBU7@BT7D(=`)R(T$`XG"`U7<BT78BP"-!`(M)$/D<(E%\(-%V`3!
M3>@"BT7PB</!RQN+5>2+1>@)T(G!(TWLBU7DBT7H(=`)R(T$`XG"`U7@BT78
MBP"-!`(M)$/D<(E%W(-%V`3!3>P"BT7<B</!RQN+5>B+1>P)T(G!(TWPBU7H
MBT7L(=`)R(T$`XG"`U7DBT78BP"-!`(M)$/D<(E%X(-%V`3!3?`"BT7@B</!
MRQN+5>R+1?`)T(G!(TW<BU7LBT7P(=`)R(T$`XG"`U7HBT78BP"-!`(M)$/D
M<(E%Y(-%V`3!3=P"BT7DB</!RQN+5?"+1=P)T(G!(TW@BU7PBT7<(=`)R(T$
M`XG"`U7LBT78BP"-!`(M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+5=R+1>`)
MT(G!(TWDBU7<BT7@(=`)R(T$`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!
M3>0"BT7LB</!RQN+5>"+1>0)T(G!(TWHBU7@BT7D(=`)R(T$`XG"`U7<BT78
MBP"-!`(M)$/D<(E%\(-%V`3!3>@"BT7PB</!RQN+5>2+1>@)T(G!(TWLBU7D
MBT7H(=`)R(T$`XG"`U7@BT78BP"-!`(M)$/D<(E%W(-%V`3!3>P"BT7<B</!
MRQN+5>B+1>P)T(G!(TWPBU7HBT7L(=`)R(T$`XG"`U7DBT78BP"-!`(M)$/D
M<(E%X(-%V`3!3?`"BT7@B</!RQN+5>R+1?`)T(G!(TW<BU7LBT7P(=`)R(T$
M`XG"`U7HBT78BP"-!`(M)$/D<(E%Y(-%V`3!3=P"BT7DB</!RQN+5?"+1=P)
MT(G!(TW@BU7PBT7<(=`)R(T$`XG"`U7LBT78BP"-!`(M)$/D<(E%Z(-%V`3!
M3>`"BT7HB</!RQN+5=R+1>`)T(G!(TWDBU7<BT7@(=`)R(T$`XG"`U7PBT78
MBP"-!`(M)$/D<(E%[(-%V`3!3>0"BT7LB</!RQN+5>"+1>0)T(G!(TWHBU7@
MBT7D(=`)R(T$`XG"`U7<BT78BP"-!`(M)$/D<(E%\(-%V`3!3>@"BT7PB</!
MRQN+5>2+1>@)T(G!(TWLBU7DBT7H(=`)R(T$`XG"`U7@BT78BP"-!`(M)$/D
M<(E%W(-%V`3!3>P"BT7<B</!RQN+5>B+1>P)T(G!(TWPBU7HBT7L(=`)R(T$
M`XG"`U7DBT78BP"-!`(M)$/D<(E%X(-%V`3!3?`"BT7@B</!RQN+5>R+1?`)
MT(G!(TW<BU7LBT7P(=`)R(T$`XG"`U7HBT78BP"-!`(M)$/D<(E%Y(-%V`3!
M3=P"BT7DB</!RQN+5?"+1=P)T(G!(TW@BU7PBT7<(=`)R(T$`XG"`U7LBT78
MBP"-!`(M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+5=R+1>`)T(G!(TWDBU7<
MBT7@(=`)R(T$`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!3>0"BT7LB<'!
MR1N+5>2+1>@QT#-%X(T$`8G"`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!3>@"
MBT7PB<'!R1N+5>B+1>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%
MV`3!3>P"BT7<B<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=
M-8E%X(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-
M!`(M*CZ=-8E%Y(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7L
MBT78BP"-!`(M*CZ=-8E%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$
M`8G"`U7PBT78BP"-!`(M*CZ=-8E%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@Q
MT#-%X(T$`8G"`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!3>@"BT7PB<'!R1N+
M5>B+1>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%V`3!3>P"BT7<
MB<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=-8E%X(-%V`3!
M3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(M*CZ=-8E%
MY(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78BP"-!`(M
M*CZ=-8E%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"`U7PBT78
MBP"-!`(M*CZ=-8E%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%X(T$`8G"
M`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!3>@"BT7PB<'!R1N+5>B+1>PQT#-%
MY(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%V`3!3>P"BT7<B<'!R1N+5>R+
M1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=-8E%X(-%V`3!3?`"BT7@B<'!
MR1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(M*CZ=-8E%Y(-%V`3!3=P"
MBT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78BP"-!`(M*CZ=-8E%Z(-%
MV`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"`U7PBT78BP"-!`(M*CZ=
M-8E%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%X(T$`8G"`U7<BT78BP"-
M!`(M*CZ=-8E%\(-%V`3!3>@"BT7PB<'!R1N+5>B+1>PQT#-%Y(T$`8G"`U7@
MBT78BP"-!`(M*CZ=-8E%W(-%V`3!3>P"BT4(BP")P@-5W(M%"(D0BT4(BT`$
MB<(#5?"+10B)4`2+10B+0`B)P@-5[(M%"(E0"(M%"(M`#(G"`U7HBT4(B5`,
MBT4(BT`0B<(#5>2+10B)4!"!Q'`!``!;7<-5B>6+10C'``$C16>+10C'0`2)
MJ\WOBT4(QT`(_MRZF(M%",=`#'94,A"+10C'0!#PX=+#BT4(QT`4`````(M%
M",=`&`````"+10C'0%P`````7<-5B>6#[!B+10B+4!2+11#!X`.-!`*)1?B+
M10B+0!0[1?AV#XM%"(M`&(U0`8M%"(E0&(M5"(M%^(E"%(M%"(M0&(M%$,'H
M'0'"BT4(B5`8BT4(BT!<A<`/A)\```"+10B+4%RX0````"G0B47\BT7\.T40
M?@:+11")1?R+3?R+10B-4!R+10B+0%R-!`*#[`11_W4,4.B[W/__@\00BT7\
M*440BT7\`44,BT4(BT!<B<(#5?R+10B)4%R+10B+0%R#^$!U7_]U".@0[/__
M@\0$ZRJ+10B#P!R#[`1J0/]U#%#H;]S__X/$$(-%#$"#;1!`_W4(Z.3K__^#
MQ`2#?1`_?]"+51"+10B#P!R#[`12_W4,4.@]W/__@\00BU4(BT40B4)<R<-5
MB>7_=0SHK.O__X/$!(M%#(L`P>@8B,*+10B($(M%"(U0`8M%#(L`P>@0B`*+
M10B-4`*+10R+`,'H"(@"BT4(C5`#BT4,BP"(`HM%"(U0!(M%#(M`!,'H&(@"
MBT4(C5`%BT4,BT`$P>@0B`*+10B-4`:+10R+0`3!Z`B(`HM%"(U0!XM%#(M`
M!(@"BT4(C5`(BT4,BT`(P>@8B`*+10B-4`F+10R+0`C!Z!"(`HM%"(U0"HM%
M#(M`",'H"(@"BT4(C5`+BT4,BT`(B`*+10B-4`R+10R+0`S!Z!B(`HM%"(U0
M#8M%#(M`#,'H$(@"BT4(C5`.BT4,BT`,P>@(B`*+10B-4`^+10R+0`R(`HM%
M"(U0$(M%#(M`$,'H&(@"BT4(C5`1BT4,BT`0P>@0B`*+10B-4!*+10R+0!#!
MZ`B(`HM%"(U0$XM%#(M`$(@"R<-5B>6#[!B+10R+0!2)1?B+10R+0!B)1?2+
M1?C!Z`.#X#^)1?R+10R-4!R+1?R-!`+&`(#_1?R#??PX?DBX0````"M%_(G!
MBT4,C5`<BT7\C00"@^P$46H`4.A!V?__@\00_W4,Z/[I__^#Q`2+10R#P!R#
M[`1J.&H`4.@@V?__@\00ZR6X.````"M%_(G!BT4,C5`<BT7\C00"@^P$46H`
M4.CYV/__@\00BT7TP>@8B,*+10R(4%2+1?3!Z!"(PHM%#(A058M%],'H"(C"
MBT4,B%!6BT7TB,*+10R(4%>+1?C!Z!B(PHM%#(A06(M%^,'H$(C"BT4,B%!9
MBT7XP>@(B,*+10R(4%J+1?B(PHM%#(A06_]U#/]U".B2_?__@\0(R<-5B>6#
M[!C'1?P`````QT7X`````.@#VO__B47T@WWT`'09@^P,_W7TZ,_9__^#Q!")
M1?B+1?B+`(E%_(M%_,G#58GE5U93@^P\QT7P`````,=%[`````"-1<R)1<#'
M1;S\V00(QT6X!@```(M]P(MUO(M-N/.EQT7D`````,=%Z`````#IQ````(/L
M#/]U\.AQWO__@\00B47L@WWL`'0)BT7LB@"$P'46@^P(_W4(_W7PZ&C>__^#
MQ!#IBP```(/L"/]U"/]U[.B?V?__@\00A<!U=H/L#/]U".C]V/__@\00B<.A
MG$@%"(/L#%#HZMC__X/$$`'#@^P,_W7LZ-K8__^#Q!"-!`.#P`*#[`Q0Z&C9
M__^#Q!")1>2AG$@%"(/L#/]U[%#_=0AHZ=@$"/]UY.@6UO__@\0@@^P(_W7D
M_W7PZ-C=__^#Q!#_1>B+1>B+1(7,B47PBT7PB@"$P`^%)?___XUE]%M>7UW#
M58GE5U93@>PL@0``BT4(B87@?O__9:$4````B47P,<#'A41___\`````QX5`
M?___`````,>%/'___P````#'A?Q^__]$V@0(QX4`?___3-H$",>%!'___^?8
M!`C'A0A____ZV00(C97D?O__B978?O__QX74?O__+-H$",>%T'[__P8```"+
MO=A^__^+M=1^__^+C=!^___SI<>%#'___U':!`C'A1!___]6V@0(QX44?___
M^MD$",>%.'___U_:!`C'A31____ZV00(QX4P?___`````,>%+'___P````#'
MA2A___\`````QX48?___`````(/L#&C1V`0(Z)C<__^#Q!")A3Q___^#O3Q_
M__\`=#F+A3Q___^*`(3`="V#[`S_M3Q____HI_W__X/$$(/L#/^U/'___^@"
MV?__@\00B87<?O__Z=H&``#H0_W__XF%+'___X.]+'___P!U<<>%3'___P``
M``#K/8/L#/^U0'___^@?W/__@\00B84\?___@[T\?___`'07@^P,_[4\?___
MZ*;8__^#Q!")A2Q_____A4Q___^#O2Q___\`=1^+A4Q___^+A(4,?___B85`
M?___BX5`?___B@"$P'6;@[TL?___`'4,QX4L?___9-H$".M/BX4L?___B85(
M?___ZS7H]]7__XL0BX5(?___B@`/OL`!P(T$`F:+`"7__P``@^`(A<!U"8N%
M2'___\8`7_^%2'___XN%2'___XH`A,!UO\>%3'___P````#I!0$``(/L#/^U
M0'___^A'V___@\00B84\?___@[T\?___``^$VP```(/L#&H`Z-[7__^#Q!"+
M`(/L#%#HP-3__X/$$(/L#%#HY-;__X/$$(/L"%#_M3Q____H_A,``(/$$(7`
M#X6:````@^P,:@#HG=?__X/$$(L`@^P,4.A_U/__@\00@^P,4.BCUO__@\00
MBT`0)0#P```]`$```'0V@^P,:@#H9]?__X/$$(L`@^P,4.A)U/__@\00@^P,
M4.AMUO__@\00BT`0)0#P```]`*```'4N@^P(:@+_M3Q____HB]3__X/$$(7`
M=1>#[`S_M3Q____H!M?__X/$$(F%1'____^%3'___X.]1'___P!U(XN%3'__
M_XN$A>1^__^)A4!___^+A4!___^*`(3`#X7/_O__QX5,?___`````.GA````
M@^P,:@#HPM;__X/$$(L`@^P,4.BDT___@\00@^P,4.C(U?__@\00@^P(4/^U
M/'___^CB$@``@\00A<`/A9H```"#[`QJ`.B!UO__@\00BP"#[`Q0Z&/3__^#
MQ!"#[`Q0Z(?5__^#Q!"+0!`E`/```#T`0```=#:#[`QJ`.A+UO__@\00BP"#
M[`Q0Z"W3__^#Q!"#[`Q0Z%'5__^#Q!"+0!`E`/```#T`H```=2Z#[`AJ`O^U
M/'___^AOT___@\00A<!U%X/L#/^U/'___^CJU?__@\00B85$?____X5,?___
M@[U$?___`'4CBX5,?___BX2%_'[__XF%/'___XN%/'___XH`A,`/A?/^__^#
M[`S_M41____HT=/__X/$$(G#@^P,_[4X?___Z+[3__^#Q!`!PX/L#/^U+'__
M_^BKT___@\00`<.#[`S_M31____HF-/__X/$$(T$`P4`!```B848?___BX48
M?___@^P,4.@8U/__@\00B84H?___H9A(!0B#[`C_M2Q_____M3A___]0_[5$
M?___:&O:!`C_M2A____HM-#__X/$((/L"&CM`0``_[4H?___Z,[0__^#Q!"#
M[`QHX]D$".A'V/__@\00B84\?___@^P,_[4\?___Z-?4__^#Q!")PHN%X'[_
M_XL`@^P(4E#HR-O__X/$$(F%,'___X.],'___P!U#HN%X'[__XL`B84P?___
MZ-GA__^%P`^%`@(``(/L"&H`_[4P?___Z$/4__^#Q!")A21___^#O21___\`
M#X3<`0``:@)J_VKN_[4D?___Z.S0__^#Q!"#[`1J!HV%4'___U#_M21____H
M4M'__X/$$(J%4'___X3`#X6=````BH51?___/$,/A8\```"*A5)___\\00^%
M@0```(J%4W___SQ#=7>*A51___\\2'5MBH55?___/$5U8VH":O]JQO^U)'__
M_^AVT/__@\00@^P$:BF-A5!___]0_[4D?___Z-S0__^#Q!"+%9A(!0B#[`C_
MM31___^-A5!___]04O^U*'___VATV@0(_[4H?___Z#S/__^#Q"#I1P$``(V%
M4/___U#H[_/__X/$!.L?@^P$_[4@?___C850?___4(V%4/___U#H(O3__X/$
M$(/L!&@`@```C850?___4/^U)'___^A:T/__@\00B84@?___@[T@?___`'^U
M@^P,_[4D?___Z,K1__^#Q!"#[`B-A5#___]0C47<4.A%]O__@\00QX4<?___
M`````.LXBX4<?___BD0%W+D`````B,&+A1Q___\!P(G"C46S`="#[`11:(/:
M!`A0Z';.__^#Q!#_A1Q___^#O1Q___\3?K_&1=L`BQ682`4(@^P(_[4T?___
MC46S4%+_M2A___]H=-H$"/^U*'___^@VSO__@\0@ZT2#[`AHF-D$"&@,V00(
MZ/+5__^#Q!#H-\[__XL5F$@%"(/L"/^U-'___U!2_[4H?___:(C:!`C_M2A_
M___H\,W__X/$((/L"/^U*'___VC1V`0(Z*W5__^#Q!"#[`S_M2A____HO?;_
M_X/$$(N%*'___XF%W'[__XN%W'[__XM5\&4S%10```!T!>CST/__C67T6UY?
M7<-5B>53@^QTQT7P`````(/L#/]U".ARS___@\00B47X@WWX``^$.`$``.GV
M````BT7T@\`3@^P(:.?8!`A0Z.G1__^#Q!"%P`^$UP```(M%](/`$X/L"&B6
MV@0(4.C*T?__@\00A<`/A+@```"#[`S_=0CHM,___X/$$(G#BT7T@\`3@^P,
M4.B@S___@\00C00#@\`"B47LBT7L@^P,4.@HT/__@\00B47PBT7T@\`34/]U
M"&B9V@0(_W7PZ-O,__^#Q!"#[`B-18Q0_W7PZ%4-``"#Q!"#^/]T)XM%G"4`
M\```/0!```!U&(-]#`!T$H/L"&H!_W7PZ`3___^#Q!#K#H/L#/]U\.@OS___
M@\00@^P,_W7PZ"'.__^#Q!#'1?``````@^P,_W7XZ,S.__^#Q!")1?2#??0`
M#X7O_O__@^P,_W7XZ$'/__^#Q!"#?0@`=`Z#[`S_=0CHG<___X/$$(M=_,G#
M58GE@^P8@^P,_W4(Z*':__^#Q!")1?S_=?SH5]K__X/$!(E%^.BIW?__A<!T
M1X-]"`!T08M%"(H`A,!T.(/L"&A?V@0(_W7XZ`C/__^#Q!`[1?AU((/L"&H!
M_W4(Z#C^__^#Q!"#[`AJ`/]U_.@H_O__@\00R<-5B>53@^P4@^P,:@#H'=#_
M_X/$$(L`@^P,4.C_S/__@\00@^P,4.BCR___@\00BP"+6`2#[`QJ`.CQS___
M@\00BP"#[`Q0Z-/,__^#Q!"#[`Q0Z!?,__^#Q!"*`(A#&(/L#&H`Z,7/__^#
MQ!"+`(/L#%#HI\S__X/$$(/L#%#H2\O__X/$$(L`BU@$@^P,:@#HF<___X/$
M$(L`@^P,4.A[S/__@\00@^P,4.C/R___@\00BP"+0!`E_P$``&:)0QJ#[`QJ
M`.ADS___@\00BP"#[`Q0Z$;,__^#Q!"#[`Q0Z.K*__^#Q!"+`(M8!(/L#&H`
MZ#C/__^#Q!"+`(/L#%#H&LS__X/$$(/L!&H`:/K9!`A0Z)?.__^#Q!")0QR#
M[`QJ`.@'S___@\00BP"#[`Q0Z.G+__^#Q!"#[`Q0Z(W*__^#Q!"+`(M8!(/L
M#&H`Z-O.__^#Q!"+`(/L#%#HO<O__X/$$(/L#%#HX<K__X/$$(L`B4,@@^P,
M:@#HK\[__X/$$(L`@^P,4.B1R___@\00@^P,4.@URO__@\00BP"+0`2)1?2#
M[`QJ`.B`SO__@\00BP"#[`Q0Z&++__^#Q!"#[`Q0Z';-__^#Q!"+`(7`=#&#
M[`QJ`.A3SO__@\00BP"#[`Q0Z#7+__^#Q!"#[`Q0Z$G-__^#Q!"+`(M`;(E%
M^.L'QT7X`````(M5^(M%](E0)(/L#&H`Z!+.__^#Q!"+`(/L#%#H],K__X/$
M$(/L#%#HF,G__X/$$(L`BT`$QT`H`````(/L#&H`Z-_-__^#Q!"+`(/L#%#H
MP<K__X/$$(/L#%#H9<G__X/$$(L`BT`$QT`L`````(/L#&H`Z*S-__^#Q!"+
M`(/L#%#HCLK__X/$$(/L#%#H,LG__X/$$(L`BU@$@^P,:@#H@,W__X/$$(L`
M@^P,4.ABRO__@\00@^P,4.@FS?__@\00BP")0S"+7?S)PU6)Y8/L"(/L#&H`
MZ$G-__^#Q!"+`(/L#%#H*\K__X/$$(/L"&K_4.AMRO__@\00@^P,:@#H(,W_
M_X/$$(L`@^P,4.@"RO__@\00@^P$:@!HALL$"%#H3\W__X/$$,G#58GE5E.#
M[##'1>``````@^P,:@#HX<S__X/$$(L`@^P,4.C#R?__@\00@^P,4.@WRO__
M@\00Q@`!@^P,:/#8!`CH_<___X/$$(E%W(-]W`!T$XM%W(H`/#%U"HM%W$"*
M`(3`=`7HR=?__X/L#&H`Z(;,__^#Q!"+`(/L#%#H:,G__X/$$&H+:@%HG]H$
M"%#H%LG__X/$$(E%](-]]``/A"H!``"+1?2+0`R+0!B)1?#'1>0!````Z;8`
M``"+1>2-6/^#[`QJ`.@NS/__@\00BP"#[`Q0Z!#)__^#Q!!J`%/_=?!0Z('*
M__^#Q!")1>R#?>P`#X2'````BT7LBP"+0`@E``0``(7`=`V+1>R+`(M`#(E%
MR.LQBT7LBQB#[`QJ`.C4R___@\00BP"#[`Q0Z+;(__^#Q!!J`FH`4U#H&,S_
M_X/$$(E%R(L5#%D%"(M%Y,'@`HT$`HL`@^P(_W7(4.BUR___@\00A<!U%/]%
MX/]%Y*$(604(.47D#XP\____H0A9!0A(.T7@=4/'1>0!````ZS"#[`QJ`.A<
MR___@\00BP"#[`Q0Z#[(__^#Q!"#[`C_=?!0Z-_'__^#Q!")1>C_1>2A"%D%
M"#E%Y'S&@^P,:@#H(LO__X/$$(L`@^P,4.@$R/__@\00:@5J`6BDV@0(4.BR
MQ___@\00B47T@WWT`'1YBT7TBT`,BQB#[`QJ`.CDRO__@\00BP"#[`Q0Z,;'
M__^#Q!"#[`1HIMH$"%-0Z)3'__^#Q!"+1?2+0`R+`(M`""4``$``A<!T,(M%
M](M`#(L8@^P,:@#HF\K__X/$$(L`@^P,4.A]Q___@\00@^P(4U#H4,G__X/$
M$(/L#&H`Z'/*__^#Q!"+`(/L#%#H5<?__X/$$&H%:@%HJ]H$"%#H`\?__X/$
M$(E%](-]]``/A(T```#'1=@`````@^P,:-K8!`CH>,W__X/$$(E%V(-]V`!T
M-8M%](M`#(L8@^P,:@#H$<K__X/$$(L`@^P,4.CSQO__@\00@^P$_W784U#H
MP\;__X/$$.LXH0Q9!0B+&(M%](M`#(LP@^P,:@#HU<G__X/$$(L`@^P,4.BW
MQO__@\00@^P$4U90Z"W+__^#Q!"#[`QJ`.BLR?__@\00BP"#[`Q0Z([&__^#
MQ!"#[`Q0Z`+'__^#Q!#&``"#[`QJ`.B"R?__@\00BP"#[`Q0Z&3&__^#Q!"#
M[`Q0Z)C)__^#Q!#'``````"#[`QHT=@$".B;S/__@\00HP19!0BA!%D%"(7`
M#X7Z````H0Q9!0B#[`Q0Z-_N__^#Q!"C!%D%"*$,604(B47,BT7TBT`,BP"+
M0`@E``0``(7`=!"+1?2+0`R+`(M`#(E%T.LTBT7TBT`,BQB#[`QJ`.CIR/__
M@\00BP"#[`Q0Z,O%__^#Q!!J`FH`4U#H+<G__X/$$(E%T(/L"/]US/]UT.C)
MQO__@\00B47DBT7TBT`,BP"+0`@E``0``(7`=!"+1?2+0`R+`(M`#(E%U.LT
MBT7TBT`,BQB#[`QJ`.A]R/__@\00BP"#[`Q0Z%_%__^#Q!!J`FH`4U#HP<C_
M_X/$$(E%U*$,604(BP#_=>3_==10:+#:!`CHD\?__Z$$604(@^P(:.T!``!0
MZ/##__^#Q!")1>2#?>0`="B#?>01="*#?>3_=!RA!%D%"(L5#%D%"(L2_W7D
M4%)HX-H$".A,Q___C67X6UY=PU6)Y8/L"(/L#&H`Z.7'__^#Q!"+`(/L#%#H
MQ\3__X/$$(/L#%#H_\C__X/$$(/L#&H`Z+['__^#Q!"+`(/L#%#HH,3__X/$
M$(/L"&H`:/K9!`AH^MD$"&BZS@0(:"[;!`A0Z%[%__^#Q"#)PXU,)`2#Y/#_
M<?Q5B>51@^P4B4WH@^P$BT7H@\`(4(M%Z(/`!%#_=>CH/,?__X/$$(/L!&BD
MEP0(:*27!`AH=)D$".B^`@``@\00@^P,:@#H5<3__X/$$(H`A,!U6.@WQ/__
MHP!9!0BA`%D%"(7`=0J#[`QJ`>A/Q___H0!9!0B#[`Q0Z.'$__^#Q!"#[`QJ
M`.CTQO__@\00BP"#[`Q0Z-;#__^#Q!"#[`Q0Z#K&__^#Q!#&``"#[`QJ`.C*
MQO__@\00BP"#[`Q0Z*S#__^#Q!"#[`Q0Z,#&__^#Q!")PHH"@\@"B`*#[`QJ
M`.B:QO__@\00BP"#[`Q0Z'S#__^#Q!"#[`Q0Z)#&__^#Q!")PHH"@\@!B`*+
M5>B+`H/`!;H`````4E#?+"2-9"0(V>[>P=T%4-L$"-G)W^G=V`^7P(/P`83`
M=0V#[`QHQ$@%".B'Q?__BTWHBP&#P`7!X`*#[`Q0Z)/%__^#Q!"C#%D%"(L5
M#%D%"(M-Z(M!!(L`B0*A#%D%"(/`!,<`0]L$"*$,604(@\`(QP"`VP0(QP4(
M604(`P```(L5#%D%"*$(604(P>`"C00"QP!&VP0(H0A9!0A`HPA9!0C'1?0!
M````ZS2+#0Q9!0BA"%D%"`-%](G"N`$````IT,'@`O?8`<&+1>B+4`2+1?3!
MX`*-!`*+`(D!_T7TBU7HBP(Y1?1\PHL-#%D%"(M%Z(L0H0A9!0B-!`*)PK@!
M````*=#!X`+WV(T$`<<``````(L-#%D%"(M%Z(L0H0A9!0B-!`)(BQ4`604(
M@^P,:@!14&B_TP0(4N@&P?__@\0@B47X@WWX`'44H0!9!0B#[`Q0Z)S!__^#
MQ!")1?BA`%D%"(/L#%#HF,/__X/$$(/L#&@`V00(Z#'(__^#Q!"%P'4XH019
M!0B%P'45@^P,:-'8!`CH%,C__X/$$*,$604(H019!0B%P'01H019!0B#[`Q0
MZ`?T__^#Q!"A`%D%"(/L#%#H:\#__X/$$.@CPO__BT7XBTW\R8UA_,.0D)"0
M58GE4^@`````6X'#$W```(N#2`$``(M-$%"+50R+10A14E#HS,#__XM=_,G#
MD)"058GE7<.-="8`C;PG`````%6)Y5=64X/L#.@`````6X'#SF\``.AZO___
MC8/P_O__C9/P_O__*=")Q\'_`G0E,?:-M"8`````BTT04(M5#(M%"%%24/^4
ML_#^__]&@\00.?YRY(UE]%M>7UW#D)"0D%6)Y5/H`````%N!PW-O``"+50R+
M10A24&H#Z/6___^+7?S)PY"0D)"0D)"0D)"0D%6)Y5/H`````%N!PT-O``"+
M50R+10A24&H#Z.7`__^+7?S)PY"0D)"0D)"0D)"0D%6)Y5.#[`2A/$8%"(/X
M_W03NSQ&!0AFD(/K!/_0BP.#^/]U]%A;7<-5B>53@^P$Z`````!;@</H;@``
MZ/##__]96\G#`````````````````P````$``@!P97)L>'-I+F,`1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`"]P<F]C+W-E;&8O97AE`"\`.@!E>&4`
M+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`"X`)7,E<R5S`%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'
M`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$```!?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@(```3$1?3$E"4D%265]0051(`$Q)0E!!
M5$@`3$E"4D%265]0051(`%!!5$@`1%E,1%],24)205)97U!!5$@```"^V00(
MSMD$"-;9!`CCV00(Z-D$"/K9!`A435!$25(`5$5-4$1)4@!414U0`%1-4`!A
MV00(%-H$"!O:!`@CV@0(*-H$"/K9!`A#.EQ414U0`"]T;7``55-%4@!54T52
M3D%-10!P87(M`%-94U1%30`E<R5S)7,E<P`E<R5S8V%C:&4M)7,E<P`E,#)X
M`"5S)7-T96UP+25U)7,`+BX`)7,O)7,`05)'5@`8`'!E<FP`,``````E<SH@
M97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@`E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@!);G1E<FYA;',Z.E!!
M4CHZ0D]/5``M90`M+0````````````"`____ST$``````````'!A<BYP;```
M````````````````````````````````(R$O=7-R+V)I;B]P97)L"@IE=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?
M7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@
M;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L
M:6YE(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL
M93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U
M:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@<FUD:7(@)'1O<&1I<CL*
M"B`@("!I9B`H+60@)'!A<E]T96UP*2!["B`@("`@("`@(R!3;VUE=&AI;F<@
M=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN
M("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R
M;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L
M:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL
M:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD
M('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R
M;V-E<W,N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@
M("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@
M("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@
M/3X@,"P*("`@("`@("`I.PH*("`@("`@("`C($)E8V%U<V4@=&AE('!A<E]T
M96UP(&1I<F5C=&]R>2!I<R!G;VEN9R!T;R!B92!D96QE=&5D(&EN(&$*("`@
M("`@("`C(&)A8VMG<F]U;F0@<')O8V5S<RP@=&AE('!A<F5N="!P<F]C97-S
M(&ED(&UA>2!B92!R975S960@8F5F;W)E('1H90H@("`@("`@(",@8F%C:V=R
M;W5N9"!P<F]C97-S(&-O;7!L971E<RX@(%1O(&5N<W5R92!T:&%T('1H92!T
M96UP;W)A<GD*("`@("`@("`C(&1I<F5C=&]R>2!D;V5S(&YO="!G970@<F5U
M<V5D('=H:6QE(&ET(&ES(&)E:6YG(&1E;&5T960L('1R>2!T;PH@("`@("`@
M(",@<F5N86UE(&ET('1O(&$@;F%M92!T:&%T(&ES(')E;&%T960@=&\@=&AE
M('1E;7!O<F%R>2!S8W)I<'0@9FEL92X*"B`@("`@("`@;7D@)'1M<&YA;64@
M/2`H1FEL93HZ4W!E8RT^<W!L:71P871H*"1T;7`M/F9I;&5N86UE*2E;,ET[
M(",@9FEL96YA;64*("`@("`@("`D=&UP;F%M92`]?B!S+UPN6UXN72HD+RYD
M:7(O.PH@("`@("`@(&UY("1N97=$:7(@/2!&:6QE.CI3<&5C+3YC871P871H
M*`H@("`@("`@("`@("`H1FEL93HZ4W!E8RT^<W!L:71P871H*"1P87)?=&5M
M<"DI6S`N+C%=+"`D=&UP;F%M92D["B`@("`@("`@:68@*')E;F%M92`D<&%R
M7W1E;7`L("1N97=$:7(I('L*("`@("`@("`@("`@;W5T<R@B4F5N86UE9"`D
M<&%R7W1E;7`@=&\@)&YE=T1I<B(I.PH@("`@("`@("`@("`D<&%R7W1E;7`@
M/2`D;F5W1&ER.PH@("`@("`@('T*"B`@("`@("`@:68@*"1>3R`]?B!M+W=I
M;C,R+VDI('L*("`@("`@("`@("`@<')I;G0@)'1M<"`B"CIL;V]P"G)M9&ER
M("]Q("]S(%PB)'!A<E]T96UP7"(*:68@97AI<W0@7"(D<&%R7W1E;7!<(B!G
M;W1O(&QO;W`*<FUD:7(@7"(D=&]P9&ER7"(*<FT@7"(B("X@)'1M<"T^9FEL
M96YA;64@+B`B7"(*(CL*("`@("`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@
M("`@("`@;7D@)'!R;V,["B`@("`@("`@("`@(%=I;C,R.CI0<F]C97-S.CI#
M<F5A=&4H"B`@("`@("`@("`@("`@("`D<')O8RP@)$5.5GM#3TU34$5#?2P*
M("`@("`@("`@("`@("`@("(D14Y6>T-/35-014-]("]C(%PB(B`N("1T;7`M
M/F9I;&5N86UE("X@(EPB(#YN=6P@,CYN=6P@(BP*("`@("`@("`@("`@("`@
M(#$L($Y/4DU!3%]04DE/4DE465]#3$%34RP@(BXB"B`@("`@("`@("`@("D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@)'1M<"`B(R$O
M8FEN+W-H"G=H:6QE(%L@+60@)R1P87)?=&5M<"<@73L@9&\*("`@<FT@+7)F
M("<D<&%R7W1E;7`G"F1O;F4*<FUD:7(@)R1T;W!D:7(G"G)M("<B("X@)'1M
M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T
M;7`M/F9I;&5N86UE.PH@("`@("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("`@("`@8VQO
M<V4@)'1M<#L*("`@("`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@('T*
M("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<"DI.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H
M97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@
M*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF
M(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A
M;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F
M(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@
M("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@
M7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@
M7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(
M+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@
M("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M
M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@
M("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U
M+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE
M*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]
M+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@
M("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R
M8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@
M("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@
M("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[
M(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R
M(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I
M.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.
M;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI
M>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A
M9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P
M.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S
M('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R
M97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U
M<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@
M97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP
M;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PH*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PH*
M(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T
M86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@
M("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R
M"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L
M;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y
M7W!A<@H@("`@*3L*"B`@("!M>2!`861D7W1O7VEN8SL*("`@('=H:6QE("A`
M05)'5BD@>PH@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*
M("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@979A;"`B
M=7-E("0R(CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@
M>PH@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U
M="`]("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2![
M"B`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]
M("=A;&PG.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2![
M"B`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@
M("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H
M0$%21U8I.PH*("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@
M("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$
M:7-T.PH@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]
M"@H@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0H*(R!86%@@+2T@
M861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D
M92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R
M97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"@H@("`@;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P
M87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B
M0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z
M("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@
M("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!]
M.PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@
M;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@
M("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@
M("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@
M?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@
M("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I
M(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@
M("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@
M("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@
M("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@
M("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B
M/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@
M("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M
M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP
M<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@
M(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I
M('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D[
M"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@
M/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A
M*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@
M("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@
M;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O
M;F9I9WM?9&5L:6U](&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*
M"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("1F
M:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK
M(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@
M("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@
M("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N
M97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA
M;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J
M;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@
M<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT
M96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%
M.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@
M(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,
M;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN
M*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M
M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I
M;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@
M(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM[
M"B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@
M("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@
M("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N
M9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@
M("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X]
M(")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC
M;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X
M:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL
M92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H
M92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*
M("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=]
M(#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U
M:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`[
M"B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@
M("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@
M("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z
M.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK
M*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@
M("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@
M("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@
M("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S
M=%]N86UE(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N
M+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R
M96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@
M($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I
M<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I
M<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@
M=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@
M17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE
M.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!8
M4TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ
M2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E
M<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I
M<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R.CI0<F]C97-S
M('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PI]"@HC(%1H
M92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT
M;7!D:7(N8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@
M("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F
M;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@
M("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@
M=6YL97-S("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@
M("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C
M(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@
M(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N
M86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@
M("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@
M("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@
M("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@
M("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@
M("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D
M8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N
M86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@
M("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S971?<')O9VYA
M;64@>PH@("`@:68@*"1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q
M.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@
M("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R
M971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I
M>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O
M(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U
M8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@
M("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0
M?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@
M("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@
M("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@
M;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@
M>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN
M8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G
M92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PH*,3L*"B-L:6YE(#$P,3<*"E]?14Y$7U\*``````#_____`````/____\`
M``````````$````!`````0```+("```!````O0(```$```#'`@```0````4#
M```!````.`0```P````$EP0(#0```%C8!`@$````2($$"/7^_V^@A`0(!0``
M`"R-!`@&````_(4$"`H```#9!0``"P```!`````5``````````,```!,1P4(
M`@```'`"```4````$0```!<```"4E`0($0```'R4!`@2````&````!,````(
M````_O__;^R3!`C___]O`@```/#__V\&DP0(````````````````````````
M`````````````````````````````````````````````%!&!0@`````````
M`$J7!`A:EP0(:I<$"'J7!`B*EP0(FI<$"*J7!`BZEP0(RI<$"-J7!`CJEP0(
M^I<$"`J8!`@:F`0(*I@$"#J8!`A*F`0(6I@$"&J8!`AZF`0(BI@$")J8!`BJ
MF`0(NI@$",J8!`C:F`0(ZI@$"/J8!`@*F00(&ID$""J9!`@ZF00(2ID$"%J9
M!`AJF00(>ID$"(J9!`B:F00(JID$"+J9!`C*F00(VID$".J9!`CZF00("IH$
M"!J:!`@JF@0(.IH$"$J:!`A:F@0(:IH$"'J:!`B*F@0(FIH$"*J:!`BZF@0(
MRIH$"-J:!`CJF@0(^IH$"`J;!`@:FP0(*IL$"#J;!`A*FP0(6IL$"&J;!`AZ
MFP0(BIL$")J;!`BJFP0(NIL$",J;!`C:FP0(ZIL$"/J;!`@*G`0(&IP$"```
M````````O=@$"+_8!`C_____8-L$"+=:````1T-#.B`H56)U;G1U(#0N,RXP
M+31U8G5N='4Q*2`T+C,N,2`R,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@
M*%5B=6YT=2`T+C,N,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E
M;&5A<V4I``!'0T,Z("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P
M,#@P-3`Y("AP<F5R96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N
M='4Q*2`T+C,N,2`R,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT
M=2`T+C,N,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I
M``!'0T,Z("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y
M("AP<F5R96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N='4Q*2`T
M+C,N,2`R,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT=2`T+C,N
M,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I``!'0T,Z
M("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y("AP<F5R
M96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N='4Q*2`T+C,N,2`R
M,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT=2`T+C,N,"TT=6)U
M;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN
M<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YC=&]R
M<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB
M<W,`+F-O;6UE;G0`````````````````````````````````````````````
M``````````````L````!`````@```!2!!`@4`0``$P```````````````0``
M```````3````!P````(````H@00(*`$``"````````````````0`````````
M)0````4````"````2($$"$@!``!8`P``!0`````````$````!````"$```#V
M__]O`@```*"$!`B@!```7`$```4`````````!`````0````K````"P````(`
M``#\A00(_`4``#`'```&`````0````0````0````,P````,````"````+(T$
M""P-``#9!0`````````````!`````````#L```#___]O`@````:3!`@&$P``
MY@````4``````````@````(```!(````_O__;P(```#LDP0([!,``)`````&
M`````@````0`````````5P````D````"````?)0$"'P4```8````!0``````
M```$````"````&`````)`````@```)24!`B4%```<`(```4````,````!```
M``@```!I`````0````8````$EP0(!!<``#````````````````0`````````
M9`````$````&````-)<$"#07``#P!``````````````$````!````&\````!
M````!@```#"<!`@P'```*#P`````````````$`````````!U`````0````8`
M``!8V`0(6%@``!P```````````````0`````````>P````$````"````@-@$
M"(!8``"X70`````````````@`````````(,````!`````@```#@V!0@XM@``
M!```````````````!`````````"-`````0````,````\1@4(/+8```@`````
M``````````0`````````E`````$````#````1$8%"$2V```(````````````
M```$`````````)L````!`````P```$Q&!0A,M@``!```````````````!```
M``````"@````!@````,```!01@4(4+8``/@````&``````````0````(````
MJ0````$````#````2$<%"$BW```$```````````````$````!````*X````!
M`````P```$Q'!0A,MP``1`$`````````````!`````0```"W`````0````,`
M``"02`4(D+@``!P```````````````0`````````O0````@````#````P$@%
M"*RX``!0$``````````````@`````````,(````!``````````````"LN```
M?@(``````````````0`````````!`````P``````````````*KL``,L`````
/``````````$`````````
